@@ -196,11 +196,7 @@ show_bars (GtkTreeModel *mdl,
                 
                 gtk_tree_model_get (mdl, iter, size_col, &size, -1);
 		
-		#if GLIB_CHECK_VERSION (2, 30, 0)
 			sizecstr = g_format_size (size);
-		#else
-			sizecstr = g_format_size_for_display (size);
-		#endif
 		
  		if (readelements == -1) {
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
@@ -226,11 +222,7 @@ show_bars (GtkTreeModel *mdl,
 			gtk_tree_model_get (mdl, iter, size_col, &size,
 					    -1);
 			
-			#if GLIB_CHECK_VERSION (2, 30, 0)
 				sizecstr = g_format_size (size);
-			#else
-				sizecstr = g_format_size_for_display (size);
-			#endif
 			
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
 					    COL_H_PERC, 100.0,
@@ -363,10 +355,6 @@ void
 popupmenu_list (GtkTreePath *path, GdkEventButton *event, gboolean can_trash)
 {
 	GtkWidget *pmenu;
-	gchar *path_to_string;
-
-	/* path_to_string is freed in callback function */
-	path_to_string = gtk_tree_path_to_string (path);
 
 	pmenu = gtk_menu_new ();
 
@@ -515,7 +503,7 @@ baobab_help_display (GtkWindow   *parent,
 	gboolean ret;
 
 	uri = (link_id) ? 
-		g_strdup_printf ("help:%s#%s", file_name, link_id) :
+		g_strdup_printf ("help:%s/%s", file_name, link_id) :
 		g_strdup_printf ("help:%s", file_name);
 
 	ret = gtk_show_uri (gtk_window_get_screen (parent),
