@@ -38,8 +38,8 @@
 #include <string.h>
 #include <stdarg.h>
 
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
 
 #include "gdict-defbox.h"
@@ -49,18 +49,13 @@
 #include "gdict-enum-types.h"
 #include "gdict-marshal.h"
 
-/**
- * G_UNICODE_COMBINING_MARK was deprecated on glib 2.30
- * use G_UNICODE_SPACING_MARK
- */
-
-#if !GLIB_CHECK_VERSION(2, 29, 14)
-	#define G_UNICODE_SPACING_MARK G_UNICODE_COMBINING_MARK
-#endif
-
 #define QUERY_MARGIN	48
 #define ERROR_MARGIN	24
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gdk_cursor_unref g_object_unref
+#endif
+
 typedef struct
 {
   GdictDefinition *definition;
@@ -402,7 +397,7 @@ exact_prefix_cmp (const gchar *string,
 	/* If string contains prefix, check that prefix is not followed
 	 * by a unicode mark symbol, e.g. that trailing 'a' in prefix
 	 * is not part of two-char a-with-hat symbol in string. */
-	return type != G_UNICODE_SPACING_MARK &&
+	return type != G_UNICODE_COMBINING_MARK &&
 		type != G_UNICODE_ENCLOSING_MARK &&
 		type != G_UNICODE_NON_SPACING_MARK;
 }
@@ -1897,19 +1892,19 @@ gdict_defbox_class_init (GdictDefboxClass *klass)
 
   binding_set = gtk_binding_set_by_class (klass);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_f, GDK_CONTROL_MASK,
+  			        GDK_KEY_f, GDK_CONTROL_MASK,
   			        "show-find",
   			        0);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_g, GDK_CONTROL_MASK,
+  			        GDK_KEY_g, GDK_CONTROL_MASK,
   			        "find-next",
   			        0);
   gtk_binding_entry_add_signal (binding_set,
-  				GDK_g, GDK_SHIFT_MASK | GDK_CONTROL_MASK,
+  				GDK_KEY_g, GDK_SHIFT_MASK | GDK_CONTROL_MASK,
   				"find-previous",
   				0);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_Escape, 0,
+  			        GDK_KEY_Escape, 0,
   			        "hide-find",
   			        0);
 
@@ -2862,7 +2857,11 @@ gdict_defbox_set_font_name (GdictDefbox *defbox,
   else
     font_desc = NULL;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_widget_override_font (priv->text_view, font_desc);
+#else
   gtk_widget_modify_font (priv->text_view, font_desc);
+#endif
 
   if (font_desc)
     pango_font_description_free (font_desc);
