@@ -30,8 +30,8 @@
 #include <string.h>
 #include <stdarg.h>
 
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
 #include "gdict-sidebar.h"
@@ -200,10 +200,10 @@ gdict_sidebar_select_key_press_cb (GtkWidget   *widget,
 {
   GdictSidebar *sidebar = GDICT_SIDEBAR (user_data);
 
-  if (event->keyval == GDK_space ||
-      event->keyval == GDK_KP_Space ||
-      event->keyval == GDK_Return ||
-      event->keyval == GDK_KP_Enter)
+  if (event->keyval == GDK_KEY_space ||
+      event->keyval == GDK_KEY_KP_Space ||
+      event->keyval == GDK_KEY_Return ||
+      event->keyval == GDK_KEY_KP_Enter)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
       gtk_menu_popup (GTK_MENU (sidebar->priv->menu),
