@@ -32,6 +32,7 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
 #include <libgdict/gdict.h>
@@ -1046,8 +1047,11 @@ gdict_window_cmd_edit_copy (GtkAction   *action,
 {
   g_assert (GDICT_IS_WINDOW (window));
 
-  gdict_defbox_copy_to_clipboard (GDICT_DEFBOX (window->defbox),
-		  		  gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+  if (gtk_widget_has_focus (window->entry))
+    gtk_editable_copy_clipboard (GTK_EDITABLE (window->entry));
+  else
+    gdict_defbox_copy_to_clipboard (GDICT_DEFBOX (window->defbox),
+                                    gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 }
 
 static void
@@ -1056,7 +1060,10 @@ gdict_window_cmd_edit_select_all (GtkAction   *action,
 {
   g_assert (GDICT_IS_WINDOW (window));
 
-  gdict_defbox_select_all (GDICT_DEFBOX (window->defbox));
+  if (gtk_widget_has_focus (window->entry))
+    gtk_editable_select_region (GTK_EDITABLE (window->entry), 0, -1);
+  else
+    gdict_defbox_select_all (GDICT_DEFBOX (window->defbox));
 }
 
 static void
@@ -1796,7 +1803,11 @@ gdict_window_constructor (GType                  type,
   gtk_box_pack_start (GTK_BOX (hbox), window->entry, TRUE, TRUE, 0);
   gtk_widget_show (window->entry);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  handle = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+#else
   handle = gtk_hpaned_new ();
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), handle, TRUE, TRUE, 0);
   gtk_widget_show (handle);
 
